pub trait Notifier: Send {
type Error: Display;
// Required method
fn post<T>(&self, notif: T) -> Result<(), Self::Error>
where T: Into<Notification>;
}Expand description
Applications provide a Notifier to the engine to receive engine updates
Required Associated Types
Sourcetype Error: Display
type Error: Display
The error type self can return on failure to Self::post
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".